==> diva_evaluation_cli-1.0.1-baseline-system.zip: diva_evaluation_cli-1.0.1-baseline-system/doc/cli.md <==
CLI usage
=========

Get the existing commands
-------------------------

```
actev -h
```

Get system
-------------

```
actev get-system -h 
```

### Docker

Generic command:

```
actev get-system docker -u <docker image url>
```

With username and password: 

```
actev get-system docker -u <docker image url> -U <username> -p <password>
```

:warning: if your password starts with *-* as in this example: `-9r45ijFo0`, you should write `--password=-9r45ijFo0` instead of `-p -9r45ijFo0`. Otherwise, the value will be interpreted as an argument to parse.

Example:

```
actev get-system docker -u gitlab.kitware.com:4567/diva-baseline/diva-baseline:eval_cli
```

### Git

Generic command:

```
actev get-system git -u <git repository>
```

With username and password: 

```
actev get-system git -u <git repository url> -U <username> -p <password>
```

With a token: 

```
actev get-system git -u <git repository url> -t <token>
```

Store the system in a specific directory:

```
actev get-system git -u <git repository url> ... -l <location>
```

:information_source: You can also directly add your credentials inside the url.

:warning: if your password or token starts with *-* as in this example: `-9r45ijFo0`, you should write `--password=-9r45ijFo0` instead of `-p -9r45ijFo0`. Otherwise, the value will be interpreted as an argument to parse.


Example:

```
actev get-system git -u https://gitlab.kitware.com/alexandreB/diva_evaluation_cli.git -l /tmp
```

### Other (web resources as a tar file)


Generic command:

```
actev get-system other -u <web resource url>
```

With username and password: 

```
actev get-system other -u <web resource url> -U <username> -p <password>
```

With a token: 

```
actev get-system git -u <web resource url> -t <token>
```

Store the system in a specific directory:

```
actev get-system git -u <web resource url> ... -l <location>
```

:information_source: You can also directly add your credentials inside the url.

:warning: if your password or token starts with *-* as in this example: `-9r45ijFo0`, you should write `--password=-9r45ijFo0` instead of `-p -9r45ijFo0`. Otherwise, the value will be interpreted as an argument to parse.


Example:

```
actev get-system other -u https://path/to/file.tgz -l /tmp
```

System setup
------------

```
actev system-setup
```

Design chunks
-------------
Generic command:

```
actev design-chunks -f <path to file.json> -a <path to activity.json> -o <path to output result> -n <number of video per chunks> 
```

Example:

```
actev design-chunks -f ~/file.json -a ~/activity.json -o ~/chunks.json -n 96
```

Experiment initialization
-------------------------
Generic command:

```
actev experiment-init -f <path to file.json> -a <path to activity.json> -c <path to chunks.json > -v <path to frames directory> -s <path to system cache directory>
```

Example:

```
actev experiment-init -f ~/file.json -a ~/activity.json -c ~/chunks.json -v ~/frames_location/ -s ~/system_cache_dir/
```

Pre-process a chunk
-------------------
Generic command:

```
actev pre-process-chunk -i <id of a chunk>
```

Example:

```
actev pre-process-chunk -i Chunk1
```

Process a chunk
---------------
Generic command:

```
actev process-chunk -i <id of a chunk>
```

Example:

```
actev process-chunk -i Chunk1
```

Post process a chunk
--------------------
Generic command:

```
actev post-process-chunk -i <id of a chunk>
```

Example:

```
actev post-process-chunk -i Chunk1
```

Reset a chunk
-------------
Generic command:

```
actev reset-chunk -i <id of a chunk>
```

Example:

```
actev reset-chunk -i Chunk1
```

Merge chunks
------------
Generic command:

```
actev merge-chunks -o <path to merging result> -c <path to chunks file generated during merging> -r ~/<result directory> -i <list of chunk ids>
```

Example:

```
actev merge-chunks -o ~/output.json -c ~/merging_chunks.json -r ~/system_cache_dir/ -i Chunk1 Chunk2 
```

Experiment cleanup
------------------

```
actev experiment-cleanup
```

==> diva_evaluation_cli-1.0.3-baseline-system.zip: diva_evaluation_cli-1.0.3-baseline-system/doc/cli.md <==
CLI usage
=========

Get the existing commands
-------------------------

```
actev -h
```

Get system
-------------

```
actev get-system -h 
```

### Docker

Generic command:

```
actev get-system docker -u <docker image url>
```

With username and password: 

```
actev get-system docker -u <docker image url> -U <username> -p <password>
```

:warning: if your password starts with *-* as in this example: `-9r45ijFo0`, you should write `--password=-9r45ijFo0` instead of `-p -9r45ijFo0`. Otherwise, the value will be interpreted as an argument to parse.

Example:

```
actev get-system docker -u gitlab.kitware.com:4567/diva-baseline/diva-baseline:eval_cli
```

### Git

Generic command:

```
actev get-system git -u <git repository>
```

With username and password: 

```
actev get-system git -u <git repository url> -U <username> -p <password>
```

With a token: 

```
actev get-system git -u <git repository url> -t <token>
```

Store the system in a specific directory:

```
actev get-system git -u <git repository url> ... -l <location>
```

:information_source: You can also directly add your credentials inside the url.

:warning: if your password or token starts with *-* as in this example: `-9r45ijFo0`, you should write `--password=-9r45ijFo0` instead of `-p -9r45ijFo0`. Otherwise, the value will be interpreted as an argument to parse.


Example:

```
actev get-system git -u https://gitlab.kitware.com/alexandreB/diva_evaluation_cli.git -l /tmp
```

### Other (web resources as a tar file)


Generic command:

```
actev get-system other -u <web resource url>
```

With username and password: 

```
actev get-system other -u <web resource url> -U <username> -p <password>
```

With a token: 

```
actev get-system git -u <web resource url> -t <token>
```

Store the system in a specific directory:

```
actev get-system git -u <web resource url> ... -l <location>
```

:information_source: You can also directly add your credentials inside the url.

:warning: if your password or token starts with *-* as in this example: `-9r45ijFo0`, you should write `--password=-9r45ijFo0` instead of `-p -9r45ijFo0`. Otherwise, the value will be interpreted as an argument to parse.


Example:

```
actev get-system other -u https://path/to/file.tgz -l /tmp
```

System setup
------------

```
actev system-setup
```

Design chunks
-------------
Generic command:

```
actev design-chunks -f <path to file.json> -a <path to activity.json> -o <path to output result> -n <number of video per chunks> 
```

Example:

```
actev design-chunks -f ~/file.json -a ~/activity.json -o ~/chunks.json -n 96
```

Experiment initialization
-------------------------
Generic command:

```
actev experiment-init -f <path to file.json> -a <path to activity.json> -c <path to chunks.json > -v <path to frames directory> -s <path to system cache directory>
```

Example:

```
actev experiment-init -f ~/file.json -a ~/activity.json -c ~/chunks.json -v ~/frames_location/ -s ~/system_cache_dir/
```

Pre-process a chunk
-------------------
Generic command:

```
actev pre-process-chunk -i <id of a chunk>
```

Example:

```
actev pre-process-chunk -i Chunk1
```

Process a chunk
---------------
Generic command:

```
actev process-chunk -i <id of a chunk>
```

Example:

```
actev process-chunk -i Chunk1
```

Post process a chunk
--------------------
Generic command:

```
actev post-process-chunk -i <id of a chunk>
```

Example:

```
actev post-process-chunk -i Chunk1
```

Reset a chunk
-------------
Generic command:

```
actev reset-chunk -i <id of a chunk>
```

Example:

```
actev reset-chunk -i Chunk1
```

Merge chunks
------------
Generic command:

```
actev merge-chunks -o <path to merging result> -c <path to chunks file generated during merging> -r ~/<result directory> -i <list of chunk ids>
```

Example:

```
actev merge-chunks -o ~/output.json -c ~/merging_chunks.json -r ~/system_cache_dir/ -i Chunk1 Chunk2 
```

Experiment cleanup
------------------

```
actev experiment-cleanup
```

Status
-------------

```
actev status -h
```

### System query

```
actev status system-query
```


### Experiment query

```
actev experiment-query
```

### Chunk query

Generic command:

```
actev chunk-query -i <chunk id >
```

Example:

```
actev chunk-query -i Chunk1
```
